@@ -16,7 +16,7 @@ use strict;
 use vars qw($VERSION $AUTOLOAD);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.31';
+$VERSION = '1.34';
 
 sub WritePS($$);
 sub ProcessPS($$;$);
@@ -38,6 +38,7 @@ sub ProcessPS($$;$);
         Groups => { 2 => 'Time' },
         Writable => 'string',
         PrintConv => '$self->ConvertDateTime($val)',
+        PrintConvInv => '$self->InverseDateTime($val)',
     },
     Creator     => { Priority => 0, Writable => 'string' },
     ImageData   => { Priority => 0 },
@@ -49,6 +50,7 @@ sub ProcessPS($$;$);
         Groups => { 2 => 'Time' },
         Writable => 'string',
         PrintConv => '$self->ConvertDateTime($val)',
+        PrintConvInv => '$self->InverseDateTime($val)',
     },
     Pages       => { Priority => 0 },
     Routing     => { Priority => 0, Writable => 'string' }, #2
@@ -160,7 +162,8 @@ sub PSErr($$)
 {
     my ($exifTool, $str) = @_;
     # set file type if not done already
-    $exifTool->SetFileType('PS') unless $exifTool->GetValue('FileType');
+    my $ext = $$exifTool{FILE_EXT};
+    $exifTool->SetFileType(($ext and $ext eq 'AI') ? 'AI' : 'PS');
     $exifTool->Warn("PostScript format error ($str)");
     return 1;
 }
@@ -362,7 +365,21 @@ sub ProcessPS($$;$)
 
     # set file type (PostScript or EPS)
     $raf->ReadLine($data) or $data = '';
-    $exifTool->SetFileType($data =~ /EPSF/ ? 'EPS' : 'PS');
+    my $type;
+    if ($data =~ /EPSF/) {
+        $type = 'EPS';
+    } else {
+        # read next line to see if this is an Illustrator file
+        my $line2;
+        my $pos = $raf->Tell();
+        if ($raf->ReadLine($line2) and $line2 =~ /^%%Creator: Adobe Illustrator/) {
+            $type = 'AI';
+        } else {
+            $type = 'PS';
+        }
+        $raf->Seek($pos, 0);
+    }
+    $exifTool->SetFileType($type);
 #
 # extract TIFF information from DOS header
 #
@@ -541,7 +558,6 @@ sub ProcessPS($$;$)
             $inflate or $exifTool->Warn('Error initializing inflate'), last;
             # generate a PS-like file in memory from the compressed data
             my $verbose = $exifTool->Options('Verbose');
-            my $out = $exifTool->Options('TextOut');
             if ($verbose > 1) {
                 $exifTool->VerboseDir('AI12_CompressedData (first 4kB)');
                 $exifTool->VerboseDump(\$data);
@@ -650,7 +666,7 @@ This code reads meta information from EPS (Encapsulated PostScript), PS
 
 =head1 AUTHOR
 
-Copyright 2003-2010, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2012, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
