@@ -1,7 +1,7 @@
 #------------------------------------------------------------------------------
 # File:         XMP2.pl
 #
-# Description:  Additional XMP schema definitions
+# Description:  Additional XMP namespace definitions
 #
 # Revisions:    10/12/2008 - P. Harvey Created
 #
@@ -71,12 +71,12 @@ my %sTimecode = (
     value       => { Writable => 'integer' },
 );
 
-# XMP Dynamic Media schema properties (xmpDM)
+# XMP Dynamic Media namespace properties (xmpDM)
 %Image::ExifTool::XMP::xmpDM = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-xmpDM', 2 => 'Image' },
     NAMESPACE => 'xmpDM',
-    NOTES => 'XMP Dynamic Media schema tags.',
+    NOTES => 'XMP Dynamic Media namespace tags.',
     absPeakAudioFilePath=> { },
     album               => { },
     altTapeName         => { },
@@ -383,7 +383,7 @@ my %plusImageSupplier = (
     GROUPS => { 0 => 'XMP', 1 => 'XMP-plus', 2 => 'Author' },
     NAMESPACE => 'plus',
     NOTES => q{
-        PLUS License Data Format 1.2.0 schema tags.  Note that all
+        PLUS License Data Format 1.2.0 namespace tags.  Note that all
         controlled-vocabulary tags in this table (ie. tags with a fixed set of
         values) have raw values which begin with "http://ns.useplus.org/ldf/vocab/",
         but to reduce clutter this prefix has been removed from the values shown
@@ -637,8 +637,8 @@ my %plusImageSupplier = (
     GROUPS => { 0 => 'XMP', 1 => 'XMP-prism', 2 => 'Document' },
     NAMESPACE => 'prism',
     NOTES => q{
-        Publishing Requirements for Industry Standard Metadata 2.1 schema tags. (see
-        L<http://www.prismstandard.org/>)
+        Publishing Requirements for Industry Standard Metadata 2.1 namespace
+        tags.  (see L<http://www.prismstandard.org/>)
     },
     aggregationType => { List => 'Bag' },
     alternateTitle  => { List => 'Bag' },
@@ -738,13 +738,13 @@ my %plusImageSupplier = (
 #    releaseTime
 );
 
-# PRISM Rights Language 2.1 schema (prl) (ref 2)
+# PRISM Rights Language 2.1 namespace (prl) (ref 2)
 %Image::ExifTool::XMP::prl = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-prl', 2 => 'Document' },
     NAMESPACE => 'prl',
     NOTES => q{
-        PRISM Rights Language 2.1 schema tags.  (see
+        PRISM Rights Language 2.1 namespace tags.  (see
         L<http://www.prismstandard.org/>)
     },
     geography       => { List => 'Bag' },
@@ -752,13 +752,14 @@ my %plusImageSupplier = (
     usage           => { List => 'Bag' },
 );
 
-# PRISM Usage Rights 2.1 schema (prismusagerights) (ref 2)
+# PRISM Usage Rights 2.1 namespace (prismusagerights) (ref 2)
 %Image::ExifTool::XMP::pur = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-pur', 2 => 'Document' },
     NAMESPACE => 'pur',
     NOTES => q{
-        Prism Usage Rights 2.1 schema tags.  (see L<http://www.prismstandard.org/>)
+        Prism Usage Rights 2.1 namespace tags.  (see
+        L<http://www.prismstandard.org/>)
     },
     adultContentWarning => { List => 'Bag' },
     agreement           => { List => 'Bag' },
@@ -777,12 +778,12 @@ my %plusImageSupplier = (
     usageFee            => { List => 'Bag' },
 );
 
-# DICOM schema properties (DICOM) (ref PH, written by CS3)
+# DICOM namespace properties (DICOM) (ref PH, written by CS3)
 %Image::ExifTool::XMP::DICOM = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-DICOM', 2 => 'Image' },
     NAMESPACE => 'DICOM',
-    NOTES => 'DICOM schema tags.',
+    NOTES => 'DICOM namespace tags.',
     # change some tag names to correspond with DICOM tags
     PatientName             => { },
     PatientID               => { },
@@ -804,12 +805,12 @@ my %plusImageSupplier = (
     EquipmentManufacturer   => { },
 );
 
-# PixelLive schema properties (PixelLive) (ref 3)
+# PixelLive namespace properties (PixelLive) (ref 3)
 %Image::ExifTool::XMP::PixelLive = (
     GROUPS => { 1 => 'XMP-PixelLive', 2 => 'Image' },
     NAMESPACE => 'PixelLive',
     NOTES => q{
-        PixelLive schema tags.  These tags are not writable becase they are very
+        PixelLive namespace tags.  These tags are not writable becase they are very
         uncommon and I haven't been able to locate a reference which gives the
         namespace URI.
     },
@@ -837,18 +838,75 @@ my %plusImageSupplier = (
     WorkToDo     => { },
 );
 
-# ACDSee schema (acdsee) (ref PH)
+# IDimager structures (ref PH)
+my %sTagStruct;
+%sTagStruct = (
+    STRUCT_NAME => 'TagStructure',
+    NAMESPACE => 'ics',
+    LabelName => { },
+    Reference => { },
+    ParentReference => { },
+    SubLabels => { Struct => \%sTagStruct, List => 'Bag' },
+);
+my %sSubVersion = (
+    STRUCT_NAME => 'SubVersion',
+    NAMESPACE => 'ics',
+    VersRef => { },
+    FileName => { },
+);
+
+# IDimager namespace (ics) (ref PH)
+%Image::ExifTool::XMP::ics = (
+    %xmpTableDefaults,
+    GROUPS => { 0 => 'XMP', 1 => 'XMP-ics', 2 => 'Image' },
+    NAMESPACE => 'ics',
+    NOTES => q{
+        Tags used by IDimager.  Nested TagStructure structures are unrolled to an
+        arbitrary depth of 6 to avoid infinite recursion.
+    },
+    ImageRef => { },
+    TagStructure => { Struct => \%sTagStruct, List => 'Bag' },
+    TagStructureLabelName => { Name => 'LabelName1', Flat => 1 },
+    TagStructureReference => { Name => 'Reference1', Flat => 1 },
+    TagStructureSubLabels => { Name => 'SubLables1', Flat => 1 },
+    TagStructureParentReference => { Name => 'ParentReference1', Flat => 1 },
+    TagStructureSubLabelsLabelName => { Name => 'LabelName2', Flat => 1 },
+    TagStructureSubLabelsReference => { Name => 'Reference2', Flat => 1 },
+    TagStructureSubLabelsSubLabels => { Name => 'SubLables2', Flat => 1 },
+    TagStructureSubLabelsParentReference => { Name => 'ParentReference2', Flat => 1 },
+    TagStructureSubLabelsSubLabelsLabelName => { Name => 'LabelName3', Flat => 1 },
+    TagStructureSubLabelsSubLabelsReference => { Name => 'Reference3', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabels => { Name => 'SubLables3', Flat => 1 },
+    TagStructureSubLabelsSubLabelsParentReference => { Name => 'ParentReference3', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsLabelName => { Name => 'LabelName4', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsReference => { Name => 'Reference4', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsSubLabels => { Name => 'SubLabels4', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsParentReference => { Name => 'ParentReference4', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsSubLabelsLabelName => { Name => 'LabelName5', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsSubLabelsReference => { Name => 'Reference5', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsSubLabelsSubLabels => { Name => 'SubLabels5', Flat => 1, NoSubStruct => 1 }, # break infinite recursion
+    TagStructureSubLabelsSubLabelsSubLabelsSubLabelsParentReference => { Name => 'ParentReference5', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsSubLabelsSubLabelsLabelName => { Name => 'LabelName6', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsSubLabelsSubLabelsReference => { Name => 'Reference6', Flat => 1 },
+    TagStructureSubLabelsSubLabelsSubLabelsSubLabelsSubLabelsParentReference => { Name => 'ParentReference6', Flat => 1 },
+    SubVersions => { Struct => \%sSubVersion, List => 'Bag' },
+    SubVersionsVersRef => { Name => 'SubVersionReference', Flat => 1 },
+    SubVersionsFileName => { Name => 'SubVersionFileName', Flat => 1 },
+);
+
+# ACDSee namespace (acdsee) (ref PH)
 %Image::ExifTool::XMP::acdsee = (
     %xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-acdsee', 2 => 'Image' },
     NAMESPACE => 'acdsee',
     NOTES => q{
-        ACD Systems ACDSee schema tags.
+        ACD Systems ACDSee namespace tags.
 
         (A note to software developers: Re-inventing your own private tags instead
-        of using the equivalent tags in standard XMP schemas defeats one of the most
-        valuable features of metadata: interoperability.  Your applications mumble
-        to themselves instead of speaking out for the rest of the world to hear.)
+        of using the equivalent tags in standard XMP namespaces defeats one of the
+        most valuable features of metadata: interoperability.  Your applications
+        mumble to themselves instead of speaking out for the rest of the world to
+        hear.)
     },
     author     => { Avoid => 1, Groups => { 2 => 'Author' } },
     caption    => { Avoid => 1 },
@@ -873,23 +931,23 @@ my %plusImageSupplier = (
     },
 );
 
-# Picture Licensing Universal System schema properties (xmpPLUS)
+# Picture Licensing Universal System namespace properties (xmpPLUS)
 %Image::ExifTool::XMP::xmpPLUS = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-xmpPLUS', 2 => 'Author' },
     NAMESPACE => 'xmpPLUS',
-    NOTES => 'XMP Picture Licensing Universal System (PLUS) schema tags.',
+    NOTES => 'XMP Picture Licensing Universal System (PLUS) namespace tags.',
     CreditLineReq   => { Writable => 'boolean' },
     ReuseAllowed    => { Writable => 'boolean' },
 );
 
-# Creative Commons schema properties (cc) (ref 5)
+# Creative Commons namespace properties (cc) (ref 5)
 %Image::ExifTool::XMP::cc = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-cc', 2 => 'Author' },
     NAMESPACE => 'cc',
     NOTES => q{
-        Creative Commons schema tags.  (see
+        Creative Commons namespace tags.  (see
         L<http://creativecommons.org/technology/xmp>)
     },
     license => { },
@@ -898,13 +956,13 @@ my %plusImageSupplier = (
     attributionURL  => { },
 );
 
-# Description Explorer schema properties (dex) (ref 6)
+# Description Explorer namespace properties (dex) (ref 6)
 %Image::ExifTool::XMP::dex = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-dex', 2 => 'Image' },
     NAMESPACE => 'dex',
     NOTES => q{
-        Description Explorer schema tags.  These tags are not very common.  The
+        Description Explorer namespace tags.  These tags are not very common.  The
         Source and Rating tags are avoided when writing due to name conflicts with
         other XMP tags.  (see L<http://www.optimasc.com/products/fileid/>)
     },
@@ -933,12 +991,12 @@ my %plusImageSupplier = (
     ffid        => { Name => 'FFID' },
 );
 
-# iView MediaPro schema properties (mediapro) (ref PH)
+# iView MediaPro namespace properties (mediapro) (ref PH)
 %Image::ExifTool::XMP::MediaPro = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-mediapro', 2 => 'Image' },
     NAMESPACE => 'mediapro',
-    NOTES => 'iView MediaPro schema tags.',
+    NOTES => 'iView MediaPro namespace tags.',
     Event       => { },
     Location    => {
         Avoid => 1,
@@ -951,12 +1009,12 @@ my %plusImageSupplier = (
     CatalogSets => { List => 'Bag' },
 );
 
-# DigiKam schema tags (ref PH)
+# DigiKam namespace tags (ref PH)
 %Image::ExifTool::XMP::digiKam = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-digiKam', 2 => 'Image' },
     NAMESPACE => 'digiKam',
-    NOTES => 'DigiKam schema tags.',
+    NOTES => 'DigiKam namespace tags.',
     CaptionsAuthorNames    => { Writable => 'lang-alt' },
     CaptionsDateTimeStamps => { Writable => 'lang-alt' },
     TagsList               => { List => 'Seq' },
@@ -964,12 +1022,12 @@ my %plusImageSupplier = (
     PickLabel              => { },
 );
 
-# SWF schema tags (ref PH)
+# SWF namespace tags (ref PH)
 %Image::ExifTool::XMP::swf = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-swf', 2 => 'Image' },
     NAMESPACE => 'swf',
-    NOTES => 'Adobe SWF schema tags.',
+    NOTES => 'Adobe SWF namespace tags.',
     type         => { Avoid => 1 },
     bgalpha      => { Name => 'BackgroundAlpha', Writable => 'integer' },
     forwardlock  => { Name => 'ForwardLock',     Writable => 'boolean' },
@@ -993,6 +1051,7 @@ my %plusImageSupplier = (
     r       => { Name => 'CellR' }, # (what is this? Radius?)
 );
 
+# MWG structures
 my %sExtensions = (
     STRUCT_NAME => 'Extensions',
     NAMESPACE   => undef, # variable namespace
@@ -1031,49 +1090,16 @@ my %sRegionStruct = (
     Extensions  => { Struct => \%sExtensions },
     seeAlso => { Namespace => 'rdfs', Resource => 1 },
 );
-my %sKeywordStruct6 = (
-    STRUCT_NAME => 'KeywordStruct6',
+my %sKeywordStruct;
+%sKeywordStruct = (
+    STRUCT_NAME => 'KeywordStruct',
     NAMESPACE   => 'mwg-kw',
     Keyword   => { },
     Applied   => { Writable => 'boolean' },
-);
-my %sKeywordStruct5 = (
-    STRUCT_NAME => 'KeywordStruct5',
-    NAMESPACE   => 'mwg-kw',
-    Keyword   => { },
-    Applied   => { Writable => 'boolean' },
-    Children  => { Struct => \%sKeywordStruct6, List => 'Bag' },
-);
-my %sKeywordStruct4 = (
-    STRUCT_NAME => 'KeywordStruct4',
-    NAMESPACE   => 'mwg-kw',
-    Keyword   => { },
-    Applied   => { Writable => 'boolean' },
-    Children  => { Struct => \%sKeywordStruct5, List => 'Bag' },
-);
-my %sKeywordStruct3 = (
-    STRUCT_NAME => 'KeywordStruct3',
-    NAMESPACE   => 'mwg-kw',
-    Keyword   => { },
-    Applied   => { Writable => 'boolean' },
-    Children  => { Struct => \%sKeywordStruct4, List => 'Bag' },
-);
-my %sKeywordStruct2 = (
-    STRUCT_NAME => 'KeywordStruct2',
-    NAMESPACE   => 'mwg-kw',
-    Keyword   => { },
-    Applied   => { Writable => 'boolean' },
-    Children  => { Struct => \%sKeywordStruct3, List => 'Bag' },
-);
-my %sKeywordStruct1 = (
-    STRUCT_NAME => 'KeywordStruct1',
-    NAMESPACE   => 'mwg-kw',
-    Keyword   => { },
-    Applied   => { Writable => 'boolean' },
-    Children  => { Struct => \%sKeywordStruct2, List => 'Bag' },
+    Children  => { Struct => \%sKeywordStruct, List => 'Bag' },
 );
 
-# MWG 2.0 region schema tags
+# MWG 2.0 region namespace tags
 %Image::ExifTool::XMP::mwg_rs = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-mwg-rs', 2 => 'Image' },
@@ -1112,7 +1138,7 @@ my %sKeywordStruct1 = (
     RegionsRegionListSeeAlso    => { Flat => 1, Name => 'RegionSeeAlso' },
 );
 
-# MWG 2.0 hierarchical keyword schema tags
+# MWG 2.0 hierarchical keyword namespace tags
 %Image::ExifTool::XMP::mwg_kw = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-mwg-kw', 2 => 'Image' },
@@ -1130,7 +1156,7 @@ my %sKeywordStruct1 = (
         Struct => {
             STRUCT_NAME => 'KeywordInfo',
             NAMESPACE   => 'mwg-kw',
-            Hierarchy => { Struct => \%sKeywordStruct1, List => 'Bag' },
+            Hierarchy => { Struct => \%sKeywordStruct, List => 'Bag' },
         },
     },
     KeywordsHierarchy => { Name => 'HierarchicalKeywords', Flat => 1 },
@@ -1148,12 +1174,12 @@ my %sKeywordStruct1 = (
     KeywordsHierarchyChildrenChildrenChildrenChildren => { Name => 'HierarchicalKeywords4Children', Flat => 1 },
     KeywordsHierarchyChildrenChildrenChildrenChildrenKeyword  => { Name => 'HierarchicalKeywords5', Flat => 1 },
     KeywordsHierarchyChildrenChildrenChildrenChildrenApplied  => { Name => 'HierarchicalKeywords5Applied', Flat => 1 },
-    KeywordsHierarchyChildrenChildrenChildrenChildrenChildren => { Name => 'HierarchicalKeywords5Children', Flat => 1 },
+    KeywordsHierarchyChildrenChildrenChildrenChildrenChildren => { Name => 'HierarchicalKeywords5Children', Flat => 1, NoSubStruct => 1 }, # break infinite recursion
     KeywordsHierarchyChildrenChildrenChildrenChildrenChildrenKeyword => { Name => 'HierarchicalKeywords6', Flat => 1 },
     KeywordsHierarchyChildrenChildrenChildrenChildrenChildrenApplied => { Name => 'HierarchicalKeywords6Applied', Flat => 1 },
 );
 
-# MWG 2.0 collections schema tags
+# MWG 2.0 collections namespace tags
 %Image::ExifTool::XMP::mwg_coll = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-mwg-coll', 2 => 'Image' },
@@ -1175,7 +1201,7 @@ my %sKeywordStruct1 = (
     CollectionsCollectionURI  => { Name => 'CollectionURI',  Flat => 1 },
 );
 
-# SVG schema properties (ref 9)
+# SVG namespace properties (ref 9)
 %Image::ExifTool::XMP::SVG = (
     GROUPS => { 0 => 'SVG', 1 => 'SVG', 2 => 'Image' },
     NAMESPACE => 'svg',
@@ -1220,7 +1246,7 @@ __END__
 
 =head1 NAME
 
-Image::ExifTool::XMP2.pl - Additional XMP schema definitions
+Image::ExifTool::XMP2.pl - Additional XMP namespace definitions
 
 =head1 SYNOPSIS
 
@@ -1228,7 +1254,7 @@ This module is loaded automatically by Image::ExifTool when required.
 
 =head1 DESCRIPTION
 
-This file contains definitions for less common XMP schemas.
+This file contains definitions for less common XMP namespaces.
 
 =head1 AUTHOR
 
